==> maGUI_2.0.tar.gz: maGUI/R/filter_sp2.R <==
filter_sp2<-function(h,...){
	try(({
		use.dat2Affy.m<-use.dat2Affy.m;use.datAgOne2.m<-use.datAgOne2.m;use.datAgTwo2.m<-use.datAgTwo2.m;use.datIllBA2.m2<-use.datIllBA2.m2;
		use.lumi_NQ.m<-use.lumi_NQ.m;use.data.matrix_Nimblegen2.m<-use.data.matrix_Nimblegen2.m;
		use.data.matrixNorm.m<-use.data.matrixNorm.m;use.data.matrix_onlineNorm.m<-use.data.matrix_onlineNorm.m;l<-l;tree<-tree;
	}),silent=TRUE)

	new<-h

	gp1=NULL;gp2=NULL;gp3=NULL;gp4=NULL;add_i=NULL;controls=NULL;tests=NULL;
	dgeF=NULL;groupsn=NULL;samp_p=NULL;samp_pn=NULL;designn=NULL;xf2=NULL;
	dat2Affy.f=NULL;datAgOne2.f=NULL;datAgTwo2.f=NULL;datIllBA2.f=NULL;lumi_NQ.f=NULL;
	data.matrix_Nimblegen2.f=NULL;data.matrixNorm.f=NULL;data.matrix_onlineNorm.f=NULL;
	groups_Affy=NULL;groups_Ag1=NULL;groups_Ag2=NULL;groups_Il_B=NULL;groups_Il_L=NULL;
	groups_N=NULL;groups_S=NULL;groups_O=NULL;
	design_Affy=NULL;design_Ag1=NULL;design_Ag2=NULL;design_Il_B=NULL;design_Il_L=NULL;
	design_N=NULL;design_S=NULL;design_O=NULL;
	samp_Affy=NULL;samp_Ag1=NULL;samp_Ag2=NULL;samp_Il_B=NULL;samp_Il_L=NULL;
	samp_N=NULL;samp_S=NULL;samp_O=NULL;


	rm(gp1,gp2,gp3,gp4,add_i,controls,tests,
	dgeF,groupsn,samp_p,samp_pn,designn,xf2,
	dat2Affy.f,datAgOne2.f,datAgTwo2.f,datIllBA2.f,lumi_NQ.f,
	data.matrix_Nimblegen2.f,data.matrixNorm.f,data.matrix_onlineNorm.f,
	groups_Affy,groups_Ag1,groups_Ag2,groups_Il_B,groups_Il_L,
	groups_N,groups_S,groups_O,
	design_Affy,design_Ag1,design_Ag2,design_Il_B,design_Il_L,
	design_N,design_S,design_O,
	samp_Affy,samp_Ag1,samp_Ag2,samp_Il_B,samp_Il_L,samp_N,samp_S,samp_O
)

	w_g<-gwindow("Select sample names",width=300,height=80,visible=FALSE)
	gp_g<-ggroup(container=w_g,horizontal=FALSE)
	size(gp_g)=c(420,280)
	gp_g_pn<-ggroup(container=gp_g,horizontal=TRUE)
	i=1
	
	gp_g_p1<-ggroup(container=gp_g,horizontal=TRUE)
	glabel("\n\t\tControls\t\t\t\t\t\t\t   Tests",container=gp_g_p1)
	gp_g_p2<-ggroup(container=gp_g,horizontal=TRUE)
	gp1<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p2,anchor=c(-1,1))
	glabel("\t",container=gp_g_p2)
	gp2<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p2,anchor=c(-1,1))
	add_i<<-i
	controls<-c();tests<-c();
	add<-gbutton("Add",border=TRUE,handler=function(h,...){
	add_i<<-add_i+1
	if(add_i<=2)
	{
		v1<-svalue(gp1)
		v2<-svalue(gp2)
		controls<<-c(v1,controls)
		tests<<-c(v2,tests)
	}
	else
	{
		v3<-svalue(gp3)
		v4<-svalue(gp4)
		controls<<-c(controls,v3)
		tests<<-c(tests,v4)
	}

	gp_g_p<-ggroup(container=gp_g,horizontal=TRUE)
	gp3<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p,anchor=c(-1,1))
	glabel("\t",container=gp_g_p)
	gp4<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p,anchor=c(-1,1))
		},container=gp_g_pn,anchor=c(-1,1)
	)
	size(add)<-c(80,25)
	
	glabel("\t\t\t\t\t\t",container=gp_g_pn)
	sf_y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(w_g)
		},container=gp_g_pn,anchor=c(1,-1)
	)
	size(sf_y)<-c(80,25)
	sf_y2<-gbutton("OK",border=TRUE,handler=function(h,...){
	svalue(sb)<-"				Please wait while Filtering.."
	if(add_i<=1)
	{
		controls<<-svalue(gp1)
		tests<<-svalue(gp2)
	}
	else
	{
		controls<<-c(controls,svalue(gp3))
		tests<<-c(tests,svalue(gp4))
	}
	dispose(w_g)
	groups<<-c()
	samp_p<<-c()
	xf2<<-NULL
	for(i in 1:length(controls))
	{
		xf<-strsplit(controls[i],",");
		yf<-strsplit(tests[i],",")
		if(i>1 && controls[i]==controls[i-1])
		{
			groups<<-c(groups,rep(paste("T",i,sep=""),length(yf[[1]])))
			samp_p<<-c(samp_p,yf[[1]])
		}
		else
		{
			groups<<-c(groups,rep(paste("C",i,sep=""),length(xf[[1]])),rep(paste("T",i,sep=""),length(yf[[1]])))
			samp_p<<-c(samp_p,xf[[1]],yf[[1]])
		}	
	}
	groupsn<<-groups
	samp_pn<<-samp_p
	groups<-as.factor(groups)
	design<-model.matrix(~groups)
	fit<-lmFit(new[,samp_pn],design)
	err<-try(fit<-lmFit(new[,samp_pn],design),silent=TRUE)
	if(length(grep("incompatible dimensions",err))!=0)gmessage("Incompatible dimensions or wrong group comparisons","Error Comparison")
	try(fit2<-eBayes(fit),silent=TRUE)
	try(dgeF<<-fit2,silent=TRUE)
	try(designn<<-design,silent=TRUE)
	try(({
		if(new==use.dat2Affy.m)
		{
			dat2Affy.f<<-dgeF
			groups_Affy<<-groupsn
			design_Affy<<-designn
			samp_Affy<<-samp_pn
			if(length(dat2Affy.f)!=0){
				visible(g1_1)<-FALSE
				l$Affymetrix$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(dat2Affy.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.datAgOne2.m)
		{
			datAgOne2.f<<-dgeF
			groups_Ag1<<-groupsn
			design_Ag1<<-designn
			samp_Ag1<<-samp_pn
			if(length(datAgOne2.f)!=0){
				visible(g1_1)<-FALSE
				l$Agilent_OneColor$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(datAgOne2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.datAgTwo2.m)
		{
			datAgTwo2.f<<-dgeF
			groups_Ag2<<-groupsn
			design_Ag2<<-designn
			samp_Ag2<<-samp_pn
			if(length(datAgTwo2.f)!=0){
				visible(g1_1)<-FALSE
				l$Agilent_TwoColor$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(datAgTwo2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.datIllBA2.m2)
		{
			datIllBA2.f<<-dgeF
			groups_Il_B<<-groupsn
			design_Il_B<<-designn
			samp_Il_B<<-samp_pn
			if(length(datIllBA2.f)!=0){
				visible(g1_1)<-FALSE
				l$Illumina_Beadarray$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(datIllBA2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.lumi_NQ.m)
		{
			lumi_NQ.f<<-dgeF
			groups_Il_L<<-groupsn
			design_Il_L<<-designn
			samp_Il_L<<-samp_pn
			if(length(lumi_NQ.f)!=0){
				visible(g1_1)<-FALSE
				l$Illumina_Lumi$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(lumi_NQ.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.data.matrix_Nimblegen2.m)
		{
			data.matrix_Nimblegen2.f<<-dgeF
			groups_N<<-groupsn
			design_N<<-designn
			samp_N<<-samp_pn
			if(length(data.matrix_Nimblegen2.f)!=0){
				visible(g1_1)<-FALSE
				l$Nimblegen$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(data.matrix_Nimblegen2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.data.matrixNorm.m)
		{
			data.matrixNorm.f<<-dgeF
			groups_S<<-groupsn
			design_S<<-designn
			samp_S<<-samp_pn
			if(length(data.matrixNorm.f)!=0){
				visible(g1_1)<-FALSE
				l$Series_Matrix$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(data.matrixNorm.f)
			}	
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.data.matrix_onlineNorm.m)
		{
			data.matrix_onlineNorm.f<<-dgeF
			groups_O<<-groupsn
			design_O<<-designn
			samp_O<<-samp_pn
			if(length(data.matrix_onlineNorm.f)!=0){
				visible(g1_1)<-FALSE
				l$Online_Data$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(data.matrix_onlineNorm.f)
			}	
			display()
		}		
	}),silent=TRUE)
	svalue(sb)<-"Done"
	},container=gp_g_pn,anchor=c(-1,1)
	)
	size(sf_y2)<-c(80,25)
	visible(w_g)<-TRUE
}

==> maGUI_2.4.tar.gz: maGUI/R/filter_sp2.R <==
filter_sp2<-function(h,...){
	try(({
		use.dat2Affy.m<-use.dat2Affy.m;use.datAgOne2.m<-use.datAgOne2.m;use.datAgTwo2.m<-use.datAgTwo2.m;use.datIllBA2.m2<-use.datIllBA2.m2;
		use.lumi_NQ.m<-use.lumi_NQ.m;use.data.matrix_Nimblegen2.m<-use.data.matrix_Nimblegen2.m;
		use.data.matrixNorm.m<-use.data.matrixNorm.m;use.data.matrix_onlineNorm.m<-use.data.matrix_onlineNorm.m;l<-l;tree<-tree;
	}),silent=TRUE)

	new<-h

	gp1=NULL;gp2=NULL;gp3=NULL;gp4=NULL;add_i=NULL;controls=NULL;tests=NULL;
	dgeF=NULL;groupsn=NULL;samp_p=NULL;samp_pn=NULL;designn=NULL;xf2=NULL;
	dat2Affy.f=NULL;datAgOne2.f=NULL;datAgTwo2.f=NULL;datIllBA2.f=NULL;lumi_NQ.f=NULL;
	data.matrix_Nimblegen2.f=NULL;data.matrixNorm.f=NULL;data.matrix_onlineNorm.f=NULL;
	groups_Affy=NULL;groups_Ag1=NULL;groups_Ag2=NULL;groups_Il_B=NULL;groups_Il_L=NULL;
	groups_N=NULL;groups_S=NULL;groups_O=NULL;
	design_Affy=NULL;design_Ag1=NULL;design_Ag2=NULL;design_Il_B=NULL;design_Il_L=NULL;
	design_N=NULL;design_S=NULL;design_O=NULL;
	samp_Affy=NULL;samp_Ag1=NULL;samp_Ag2=NULL;samp_Il_B=NULL;samp_Il_L=NULL;
	samp_N=NULL;samp_S=NULL;samp_O=NULL;


	rm(gp1,gp2,gp3,gp4,add_i,controls,tests,
	dgeF,groupsn,samp_p,samp_pn,designn,xf2,
	dat2Affy.f,datAgOne2.f,datAgTwo2.f,datIllBA2.f,lumi_NQ.f,
	data.matrix_Nimblegen2.f,data.matrixNorm.f,data.matrix_onlineNorm.f,
	groups_Affy,groups_Ag1,groups_Ag2,groups_Il_B,groups_Il_L,
	groups_N,groups_S,groups_O,
	design_Affy,design_Ag1,design_Ag2,design_Il_B,design_Il_L,
	design_N,design_S,design_O,
	samp_Affy,samp_Ag1,samp_Ag2,samp_Il_B,samp_Il_L,samp_N,samp_S,samp_O
)

	w_g<-gwindow("Select sample names",width=300,height=80,visible=FALSE)
	gp_g<-ggroup(container=w_g,fill="y")
	size(gp_g)=c(420,280)
	gp_g_pn<-ggroup(container=gp_g,fill="x")
	i=1
	
	gp_g_p1<-ggroup(container=gp_g,fill="x")
	glabel("\n\t\tControls\t\t\t\t\t\t\t   Tests",container=gp_g_p1)
	gp_g_p2<-ggroup(container=gp_g,fill="x")
	gp1<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p2,anchor=c(-1,1))
	glabel("\t",container=gp_g_p2)
	gp2<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p2,anchor=c(-1,1))
	add_i<<-i
	controls<-c();tests<-c();
	add<-gbutton("Add",border=TRUE,handler=function(h,...){
	add_i<<-add_i+1
	if(add_i<=2)
	{
		v1<-svalue(gp1)
		v2<-svalue(gp2)
		controls<<-c(v1,controls)
		tests<<-c(v2,tests)
	}
	else
	{
		v3<-svalue(gp3)
		v4<-svalue(gp4)
		controls<<-c(controls,v3)
		tests<<-c(tests,v4)
	}

	gp_g_p<-ggroup(container=gp_g,fill="x")
	gp3<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p,anchor=c(-1,1))
	glabel("\t",container=gp_g_p)
	gp4<<-gedit("",initial.msg="Samples Names",width=25,height=20,container=gp_g_p,anchor=c(-1,1))
		},container=gp_g_pn,anchor=c(-1,1)
	)
	size(add)<-c(80,25)
	
	glabel("\t\t\t\t\t\t",container=gp_g_pn)
	sf_y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(w_g)
		},container=gp_g_pn,anchor=c(1,-1)
	)
	size(sf_y)<-c(80,25)
	sf_y2<-gbutton("OK",border=TRUE,handler=function(h,...){
	svalue(sb)<-"				Please wait while Filtering.."
	if(add_i<=1)
	{
		controls<<-svalue(gp1)
		tests<<-svalue(gp2)
	}
	else
	{
		controls<<-c(controls,svalue(gp3))
		tests<<-c(tests,svalue(gp4))
	}
	dispose(w_g)
	groups<<-c()
	samp_p<<-c()
	xf2<<-NULL
	for(i in 1:length(controls))
	{
		xf<-strsplit(controls[i],",");
		yf<-strsplit(tests[i],",")
		if(i>1 && controls[i]==controls[i-1])
		{
			groups<<-c(groups,rep(paste("T",i,sep=""),length(yf[[1]])))
			samp_p<<-c(samp_p,yf[[1]])
		}
		else
		{
			groups<<-c(groups,rep(paste("C",i,sep=""),length(xf[[1]])),rep(paste("T",i,sep=""),length(yf[[1]])))
			samp_p<<-c(samp_p,xf[[1]],yf[[1]])
		}	
	}
	groupsn<<-groups
	samp_pn<<-samp_p
	groups<-as.factor(groups)
	design<-model.matrix(~groups)
	fit<-lmFit(new[,samp_pn],design)
	err<-try(fit<-lmFit(new[,samp_pn],design),silent=TRUE)
	if(length(grep("incompatible dimensions",err))!=0)gmessage("Incompatible dimensions or wrong group comparisons","Error Comparison")
	try(fit2<-eBayes(fit),silent=TRUE)
	try(dgeF<<-fit2,silent=TRUE)
	try(designn<<-design,silent=TRUE)
	try(({
		if(new==use.dat2Affy.m)
		{
			dat2Affy.f<<-dgeF
			groups_Affy<<-groupsn
			design_Affy<<-designn
			samp_Affy<<-samp_pn
			if(length(dat2Affy.f)!=0){
				visible(g1_1)<-FALSE
				l$Affymetrix$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(dat2Affy.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.datAgOne2.m)
		{
			datAgOne2.f<<-dgeF
			groups_Ag1<<-groupsn
			design_Ag1<<-designn
			samp_Ag1<<-samp_pn
			if(length(datAgOne2.f)!=0){
				visible(g1_1)<-FALSE
				l$Agilent_OneColor$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(datAgOne2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.datAgTwo2.m)
		{
			datAgTwo2.f<<-dgeF
			groups_Ag2<<-groupsn
			design_Ag2<<-designn
			samp_Ag2<<-samp_pn
			if(length(datAgTwo2.f)!=0){
				visible(g1_1)<-FALSE
				l$Agilent_TwoColor$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(datAgTwo2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.datIllBA2.m2)
		{
			datIllBA2.f<<-dgeF
			groups_Il_B<<-groupsn
			design_Il_B<<-designn
			samp_Il_B<<-samp_pn
			if(length(datIllBA2.f)!=0){
				visible(g1_1)<-FALSE
				l$Illumina_Beadarray$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(datIllBA2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.lumi_NQ.m)
		{
			lumi_NQ.f<<-dgeF
			groups_Il_L<<-groupsn
			design_Il_L<<-designn
			samp_Il_L<<-samp_pn
			if(length(lumi_NQ.f)!=0){
				visible(g1_1)<-FALSE
				l$Illumina_Lumi$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(lumi_NQ.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.data.matrix_Nimblegen2.m)
		{
			data.matrix_Nimblegen2.f<<-dgeF
			groups_N<<-groupsn
			design_N<<-designn
			samp_N<<-samp_pn
			if(length(data.matrix_Nimblegen2.f)!=0){
				visible(g1_1)<-FALSE
				l$Nimblegen$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(data.matrix_Nimblegen2.f)
			}
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.data.matrixNorm.m)
		{
			data.matrixNorm.f<<-dgeF
			groups_S<<-groupsn
			design_S<<-designn
			samp_S<<-samp_pn
			if(length(data.matrixNorm.f)!=0){
				visible(g1_1)<-FALSE
				l$Series_Matrix$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(data.matrixNorm.f)
			}	
			display()
		}
	}),silent=TRUE) 
	try(({
		if(new==use.data.matrix_onlineNorm.m)
		{
			data.matrix_onlineNorm.f<<-dgeF
			groups_O<<-groupsn
			design_O<<-designn
			samp_O<<-samp_pn
			if(length(data.matrix_onlineNorm.f)!=0){
				visible(g1_1)<-FALSE
				l$Online_Data$Filtered<<-list()
				tr<<-gtree(offspring=tree,container=g1_1)
				size(tr)<-c(300,400)
				visible(g1_1)<-TRUE
				stat_sign(data.matrix_onlineNorm.f)
			}	
			display()
		}		
	}),silent=TRUE)
	svalue(sb)<-"Done"
	},container=gp_g_pn,anchor=c(-1,1)
	)
	size(sf_y2)<-c(80,25)
	visible(w_g)<-TRUE
}
